VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "CUtil"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Option Explicit
'******* 1.20a Start *******
' Added class
'******* 1.20a End *********
Private Const NUL$ = ""             'Empty string
Private Const SEP_DIR$ = "\"        'Directory separator character
Private Const QUOTE$ = """"

Private Declare Function GetWindowsDirectory Lib "kernel32" Alias "GetWindowsDirectoryA" (ByVal lpBuffer As String, ByVal nSize As Long) As Long
Private Declare Function GetTempPath Lib "kernel32" _
         Alias "GetTempPathA" (ByVal nBufferLength As Long, _
         ByVal lpBuffer As String) As Long

Private Declare Function GetTempFileName Lib "kernel32" _
         Alias "GetTempFileNameA" (ByVal lpszPath As String, _
         ByVal lpPrefixString As String, ByVal wUnique As Long, _
         ByVal lpTempFileName As String) As Long

Enum genErrors
    genUnknownError = vbObjectError + 512 + 1000
End Enum

Private mintTabIndex As Integer

Public Property Get TabIndex() As Integer
' This property doesn't really "fit" in this class
' but there was no place better
    mintTabIndex = mintTabIndex + 1
    TabIndex = mintTabIndex
   
End Property

Public Property Get WindowsDir() As String
Attribute WindowsDir.VB_Description = "Return the PC's Windows directory. Returned  name ends in ""/""."
'-----------------------------------------------------------
' FUNCTION: GetWindowsDir
'
' Calls the windows API to get the windows directory and
' ensures that a trailing dir separator is present
'
' Returns: The windows directory
'-----------------------------------------------------------
'
    Dim sBuffer As String

    sBuffer = Space$(255)
    
    On Error GoTo ErrorRoutine
    '
    'Get the windows directory and then trim the buffer to the exact length
    'returned and add a dir sep (backslash) if the API didn't return one
    '
    If GetWindowsDirectory(sBuffer, 255) > 0 Then
        sBuffer = StripTerminator$(sBuffer)
        AddDirSep sBuffer

        WindowsDir = UCase16(sBuffer)
    Else
        WindowsDir = NUL
    End If
    
    Exit Property
    
ErrorRoutine:
    Err.Raise genUnknownError, "CUtil::WindowsDir", Err.Description
    
End Property
Public Property Get FileExists(ByVal sPathname As String) As Boolean
Attribute FileExists.VB_Description = "Receives a fully-qualified file name and returns a boolean indicating if the file exists or not."
'***************************************************************************
'Purpose: Determines whether the specified file exists
'Input: sPathName - file to check for
'Output: True if file exists, False otherwise
'***************************************************************************
    
    Dim nFileNum As Integer

    On Error Resume Next

    '
    ' If the string is quoted, remove the quotes.
    '
    sPathname = UnQuoteString(sPathname)
    '
    'Remove any trailing directory separator character
    '
    If Right$(sPathname, 1) = SEP_DIR Then
        sPathname = Left$(sPathname, Len(sPathname) - 1)
    End If

    '
    'Attempt to open the file, return value of this function is False
    'if an error occurs on open, True otherwise
    '
    nFileNum = FreeFile
    Open sPathname For Input As nFileNum

    
    FileExists = IIf(Err = 0, True, False)

    Close nFileNum

    Err = 0
    
    Exit Property
    
ErrorRoutine:
    Err.Raise genUnknownError, "CUtil::FileExists", Err.Description

End Property
Public Function MakeNumber(strInputValue As String) As String
Attribute MakeNumber.VB_Description = "Convert a string such as ""1,234-"" into a string that VB can handle as a numeric (""-1,234"") in this case)."
'***************************************************************************
'Purpose: Convert user text input into a number
'Inputs: strInputValue - The string to be converted into a number
'Outputs: Converted string if OK, otherwise the input string
'***************************************************************************
    Dim nCtr As Integer
    Dim strWork As String
    
    On Error GoTo ErrorRoutine
    
    'Remove commas and plus signs. Plus signs are ignored in any case
    'and commas if present would otherwise cause a string such as
    '1,234 to be treated as 1
    For nCtr = 1 To Len(strInputValue)
        If Mid$(strInputValue, nCtr, 1) <> "," _
            And Mid$(strInputValue, nCtr, 1) <> "+" Then
            strWork = strWork & Mid$(strInputValue, nCtr, 1)
        End If
    Next
    
    'Replace a trailing - with a leading one
    If Right$(strWork, 1) = "-" Then
        strWork = "-" & Left$(strWork, Len(strWork) - 1)
    End If
    
    If IsNumeric(strWork) Then
        MakeNumber = strWork
    Else
        MakeNumber = strInputValue
    End If
    
    Exit Function
    
ErrorRoutine:
    Err.Raise genUnknownError, "CUtil::MakeNumber", Err.Description

End Function

Private Function UnQuoteString(ByVal sQuotedString As String)
'
' This routine tests to see if sQuotedString is wrapped in quotation
' marks, and, if so, remove them.
'
    sQuotedString = Trim$(sQuotedString)

    If Mid$(sQuotedString, 1, 1) = QUOTE _
       And Right$(sQuotedString, 1) = QUOTE Then
        '
        ' It's quoted.  Get rid of the quotes.
        '
        sQuotedString = Mid$(sQuotedString, 2, Len(sQuotedString) - 2)
    End If
    UnQuoteString = sQuotedString
End Function

Private Function UCase16(ByVal str As String)
'-----------------------------------------------------------
' FUNCTION: UCase16
'
' Returns the upper-case conversion of a string
'   under 16 bits, or else returns an unmodified
'   copy of the string under 32 bits.
'
' IN: [str] - String to copy/upper-case
'
'-----------------------------------------------------------
#If Win16 Then
    UCase16 = UCase$(str)
#Else
    UCase16 = str
#End If

End Function

'-----------------------------------------------------------
' SUB: AddDirSep
' Add a trailing directory path separator (back slash) to the
' end of a pathname unless one already exists
'
' IN/OUT: [strPathName] - path to add separator to
'-----------------------------------------------------------
Private Sub AddDirSep(strPathName As String)
    If Right$(RTrim$(strPathName), Len(SEP_DIR)) <> SEP_DIR Then
        strPathName = RTrim$(strPathName) & SEP_DIR
    End If
    
End Sub

'-----------------------------------------------------------
' FUNCTION: StripTerminator
'
' Returns a string without any zero terminator.  Typically,
' this was a string returned by a Windows API call.
'
' IN: [strString] - String to remove terminator from
'
' Returns: The value of the string passed in minus any
'          terminating zero.
'-----------------------------------------------------------
Private Function StripTerminator(ByVal strString As String) As String
    Dim nZeroPos As Integer

    nZeroPos = InStr(strString, Chr$(0))
    If nZeroPos > 0 Then
        StripTerminator = Left$(strString, nZeroPos - 1)
    Else
        StripTerminator = strString
    End If
    
End Function

Public Function CreateTempFile(strPrefix As String) As String
'***************************************************************************
'Purpose: Create a unique temporary file name
'Inputs:  strPrefix - The prefix to be used as the first part of the temp
'         file name. Note: only the first 3 characters get used.
'Outputs: The temp file name
'***************************************************************************

    Dim strTmpPath As String * 512
    Dim strTmpName As String * 576
    Dim intRet As Long
    
    intRet = GetTempPath(512, strTmpPath)
    If (intRet > 0 And intRet < 512) Then
       intRet = GetTempFileName(strTmpPath, strPrefix, 0, strTmpName)
       If intRet <> 0 Then
          CreateTempFile = Left$(strTmpName, _
             InStr(strTmpName, vbNullChar) - 1)
       End If
    End If

End Function

Private Sub Class_Initialize()

    mintTabIndex = 0
    
End Sub


